/**
 * Copyright (C) 2001-2002
 * - France Telecom R&D
 * - Laboratoire Logiciels, Systemes, Reseaux - UMR 5526, CNRS-INPG-UJF
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * Release: 1.0
 *
 * Authors:
 *
 */

package org.objectweb.perseus.persistence.api;

/**
 * It defines a manager permiting to manage a persitent object.
 *
 * @author Luciano Garcia-Banuelos (Luciano.Garcia@imag.fr)
 */
public interface StorageManager {

	/**
	 * Makes persitent an object.
	 * @param context permits to access to the data support.
	 * @param obj is the exported persistent object
	 * @return the identifier of the persistent object.
	 * @throws PersistenceException
	 */
	Object export(ConnectionHolder context, Object obj) throws PersistenceException;

 	/**
	  * Makes persitent an object.
	  * @param context permits to access to the data support.
	  * @param obj is the exported persistent object
	  * @param hints helps to define the name of the persistent object.
	  * @return the identifier of the persistent object.
	  * @throws PersistenceException
	  */
	Object export(ConnectionHolder context, Object obj, Object hints) throws PersistenceException;

	/**
	 * Destroyes a persistent object
	 * @param context permits to access to the data support.
	 * @param oid is the object identifier of the removed persistent object.
	 * @throws PersistenceException
	 */
	void unexport(ConnectionHolder context, Object oid) throws PersistenceException;

	/**
	 * Destroyes a persistent object
	 * @param context permits to access to the data support.
	 * @param oid is the object identifier of the removed persistent object.
	 * @param hints helps to remove the persistent object.
	 * @throws PersistenceException
	 */
	void unexport(ConnectionHolder context, Object oid, Object hints) throws PersistenceException;

	/**
	 * Reads data of a persistent from the support object and puts them into
	 * an instance.
	 * @param context permits to access to the data support.
	 * @param oid is the identifier of the persistent object
	 * @param state is an instance of a persistent object which must be filled by
	 * the data read from the support
	 */
	void read(ConnectionHolder context, Object oid, State state) throws PersistenceException;

	/**
	 * Reads data of a persistent from the support object and puts them into
	 * an instance.
	 * @param context permits to access to the data support and to manage a
	 * prefetching context.
	 * @param oid is the identifier of the persistent object
	 * @param state is an instance of a persistent object which must be filled by
	 * the data read from the support
	 */
	void read(WorkingSet context, Object oid, State state) throws PersistenceException;

	/**
	 * Reads data of a persistent from the support object and puts them into
	 * an instance.
	 * @param context permits to access to the data support.
	 * @param oid is the identifier of the persistent object
	 * @param state the the persistent object instance which contains the data
	 * which must be written in the support
	 */
	void write(ConnectionHolder context, Object oid, State state) throws PersistenceException;

	/**
	 * Informes the Storage manager of the begining of a working set
	 * @param ws the working set which starts
	 */
	void beginWS(WorkingSet ws);

	/**
	 * Informes the Storage manager of the end of a working set
	 * @param ws the working set which finishes
	 */
	void endWS(WorkingSet ws);
}
